SyncConfig

Struct SyncConfig 

pub struct SyncConfig {
    pub retry_attempts: u32,
    pub retry_delay_ms: u64,
    pub default_strategy: ReadStrategy,
}
Configuration for a SyncEngine instance.

Fields

retry_attempts: u32

Number of times to retry a failed transport send before giving up.

retry_delay_ms: u64

Base delay in milliseconds between retry attempts.

default_strategy: ReadStrategy

Strategy used when no explicit strategy is supplied to SyncEngine::read.